from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Offset:
	"""Offset commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def get_azimuth(self) -> float:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:AZIMuth \n
		Snippet: value: float = driver.emitter.mode.beam.offset.get_azimuth() \n
		Sets the Azimuth value for the beam offset. \n
			:return: azimuth: float Range: 0 to 360
		"""
		response = self._core.io.query_str('EMITter:MODE:BEAM:OFFSet:AZIMuth?')
		return Conversions.str_to_float(response)

	def set_azimuth(self, azimuth: float) -> None:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:AZIMuth \n
		Snippet: driver.emitter.mode.beam.offset.set_azimuth(azimuth = 1.0) \n
		Sets the Azimuth value for the beam offset. \n
			:param azimuth: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(azimuth)
		self._core.io.write(f'EMITter:MODE:BEAM:OFFSet:AZIMuth {param}')

	def get_elevation(self) -> float:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:ELEVation \n
		Snippet: value: float = driver.emitter.mode.beam.offset.get_elevation() \n
		Offsets the position of the beam in both the azimuth or elevation. \n
			:return: elevation: float Range: -90 to 90
		"""
		response = self._core.io.query_str('EMITter:MODE:BEAM:OFFSet:ELEVation?')
		return Conversions.str_to_float(response)

	def set_elevation(self, elevation: float) -> None:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:ELEVation \n
		Snippet: driver.emitter.mode.beam.offset.set_elevation(elevation = 1.0) \n
		Offsets the position of the beam in both the azimuth or elevation. \n
			:param elevation: float Range: -90 to 90
		"""
		param = Conversions.decimal_value_to_str(elevation)
		self._core.io.write(f'EMITter:MODE:BEAM:OFFSet:ELEVation {param}')

	def get_frequency(self) -> float:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:FREQuency \n
		Snippet: value: float = driver.emitter.mode.beam.offset.get_frequency() \n
		Offsets the frequency of the beam. \n
			:return: frequency: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('EMITter:MODE:BEAM:OFFSet:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: EMITter:MODE:BEAM:OFFSet:FREQuency \n
		Snippet: driver.emitter.mode.beam.offset.set_frequency(frequency = 1.0) \n
		Offsets the frequency of the beam. \n
			:param frequency: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'EMITter:MODE:BEAM:OFFSet:FREQuency {param}')



from enum import Enum


# noinspection SpellCheckingInspection
class AmType(Enum):
	"""4 Members, LSB ... USB"""
	LSB = 0
	SB = 1
	STD = 2
	USB = 3


# noinspection SpellCheckingInspection
class AntennaModel(Enum):
	"""12 Members, ARRay ... USER"""
	ARRay = 0
	CARDoid = 1
	CARRay = 2
	COSecant = 3
	CUSTom = 4
	DIPole = 5
	GAUSsian = 6
	HORN = 7
	PARabolic = 8
	PLUGin = 9
	SINC = 10
	USER = 11


# noinspection SpellCheckingInspection
class AntennaModelArray(Enum):
	"""8 Members, COSine ... UNIForm"""
	COSine = 0
	COSN = 1
	CSQuared = 2
	HAMMing = 3
	HANN = 4
	PARabolic = 5
	TRIangular = 6
	UNIForm = 7


# noinspection SpellCheckingInspection
class Attitude(Enum):
	"""3 Members, CONStant ... WAYPoint"""
	CONStant = 0
	MOTion = 1
	WAYPoint = 2


# noinspection SpellCheckingInspection
class AutoManualMode(Enum):
	"""2 Members, AUTO ... MANual"""
	AUTO = 0
	MANual = 1


# noinspection SpellCheckingInspection
class Azimuth(Enum):
	"""2 Members, BEARing ... RX"""
	BEARing = 0
	RX = 1


# noinspection SpellCheckingInspection
class BarkerCode(Enum):
	"""9 Members, R11 ... R7"""
	R11 = 0
	R13 = 1
	R2A = 2
	R2B = 3
	R3 = 4
	R4A = 5
	R4B = 6
	R5 = 7
	R7 = 8


# noinspection SpellCheckingInspection
class BaseDomain(Enum):
	"""2 Members, PULSe ... TIME"""
	PULSe = 0
	TIME = 1


# noinspection SpellCheckingInspection
class BaseDomainB(Enum):
	"""2 Members, LENGth ... TIME"""
	LENGth = 0
	TIME = 1


# noinspection SpellCheckingInspection
class BbSync(Enum):
	"""3 Members, CTRigger ... UNSYnc"""
	CTRigger = 0
	TRIGger = 1
	UNSYnc = 2


# noinspection SpellCheckingInspection
class BlockSize(Enum):
	"""6 Members, _16K ... _64K"""
	_16K = 0
	_1M = 1
	_2M = 2
	_32K = 3
	_4M = 4
	_64K = 5


# noinspection SpellCheckingInspection
class BlType(Enum):
	"""2 Members, MIRRor ... OMNidirect"""
	MIRRor = 0
	OMNidirect = 1


# noinspection SpellCheckingInspection
class BpskTtype(Enum):
	"""2 Members, COSine ... LINear"""
	COSine = 0
	LINear = 1


# noinspection SpellCheckingInspection
class BpskType(Enum):
	"""2 Members, CONStant ... STANdard"""
	CONStant = 0
	STANdard = 1


# noinspection SpellCheckingInspection
class BufferSize(Enum):
	"""6 Members, _128M ... _64M"""
	_128M = 0
	_16M = 1
	_1G = 2
	_256M = 3
	_512M = 4
	_64M = 5


# noinspection SpellCheckingInspection
class ChirpType(Enum):
	"""5 Members, DOWN ... UP"""
	DOWN = 0
	PIECewise = 1
	SINE = 2
	TRIangular = 3
	UP = 4


# noinspection SpellCheckingInspection
class CircularMode(Enum):
	"""2 Members, RPM ... SEC"""
	RPM = 0
	SEC = 1


# noinspection SpellCheckingInspection
class Coding(Enum):
	"""4 Members, DGRay ... NONE"""
	DGRay = 0
	DIFFerential = 1
	GRAY = 2
	NONE = 3


# noinspection SpellCheckingInspection
class Complexity(Enum):
	"""3 Members, DIRection ... PTRain"""
	DIRection = 0
	EMITter = 1
	PTRain = 2


# noinspection SpellCheckingInspection
class Condition(Enum):
	"""4 Members, EQUal ... SMALler"""
	EQUal = 0
	GREater = 1
	NOTequal = 2
	SMALler = 3


# noinspection SpellCheckingInspection
class DataMop(Enum):
	"""20 Members, AM ... TFM"""
	AM = 0
	ASK = 1
	BKR11 = 2
	BKR13 = 3
	BKR2a = 4
	BKR2b = 5
	BKR3 = 6
	BKR4a = 7
	BKR4b = 8
	BKR5 = 9
	BKR7 = 10
	CPH = 11
	CW = 12
	FM = 13
	FSK = 14
	LFM = 15
	NLFM = 16
	PLFM = 17
	PSK = 18
	TFM = 19


# noinspection SpellCheckingInspection
class DataUnit(Enum):
	"""3 Members, DB ... WATTs"""
	DB = 0
	VOLTage = 1
	WATTs = 2


# noinspection SpellCheckingInspection
class DfType(Enum):
	"""4 Members, BACKground ... WAVeform"""
	BACKground = 0
	EMITter = 1
	PLATform = 2
	WAVeform = 3


# noinspection SpellCheckingInspection
class EnvelopeMode(Enum):
	"""2 Members, DATA ... EQUation"""
	DATA = 0
	EQUation = 1


# noinspection SpellCheckingInspection
class ExcMode(Enum):
	"""3 Members, LEVel ... WIDTh"""
	LEVel = 0
	TIME = 1
	WIDTh = 2


# noinspection SpellCheckingInspection
class FillerMode(Enum):
	"""2 Members, DURation ... TSYNc"""
	DURation = 0
	TSYNc = 1


# noinspection SpellCheckingInspection
class FillerSignal(Enum):
	"""3 Members, BLANk ... HOLD"""
	BLANk = 0
	CW = 1
	HOLD = 2


# noinspection SpellCheckingInspection
class FillerTime(Enum):
	"""2 Members, EQUation ... FIXed"""
	EQUation = 0
	FIXed = 1


# noinspection SpellCheckingInspection
class FilterType(Enum):
	"""9 Members, COS ... SOQPsk"""
	COS = 0
	FSKGauss = 1
	GAUSs = 2
	LPASs = 3
	NONE = 4
	RCOS = 5
	RECTangular = 6
	SMWRect = 7
	SOQPsk = 8


# noinspection SpellCheckingInspection
class FskType(Enum):
	"""6 Members, FS16 ... FS8"""
	FS16 = 0
	FS2 = 1
	FS32 = 2
	FS4 = 3
	FS64 = 4
	FS8 = 5


# noinspection SpellCheckingInspection
class GeneratorType(Enum):
	"""8 Members, SGT ... SW"""
	SGT = 0
	SMBB = 1
	SMBV = 2
	SMJ = 3
	SMM = 4
	SMU = 5
	SMW = 6
	SW = 7


# noinspection SpellCheckingInspection
class Geometry(Enum):
	"""4 Members, CIRCular ... RECTangular"""
	CIRCular = 0
	HEXagonal = 1
	LINear = 2
	RECTangular = 3


# noinspection SpellCheckingInspection
class HqMode(Enum):
	"""2 Members, NORMal ... TABLe"""
	NORMal = 0
	TABLe = 1


# noinspection SpellCheckingInspection
class Interpolation(Enum):
	"""2 Members, LINear ... NONE"""
	LINear = 0
	NONE = 1


# noinspection SpellCheckingInspection
class IpmMode(Enum):
	"""2 Members, INDividual ... SAME"""
	INDividual = 0
	SAME = 1


# noinspection SpellCheckingInspection
class IpmPlotView(Enum):
	"""2 Members, HISTogram ... TIMeseries"""
	HISTogram = 0
	TIMeseries = 1


# noinspection SpellCheckingInspection
class IpmType(Enum):
	"""10 Members, BINomial ... WAVeform"""
	BINomial = 0
	EQUation = 1
	LIST = 2
	PLUGin = 3
	RANDom = 4
	RLISt = 5
	RSTep = 6
	SHAPe = 7
	STEPs = 8
	WAVeform = 9


# noinspection SpellCheckingInspection
class ItemPattern(Enum):
	"""12 Members, ALT ... ZERO"""
	ALT = 0
	ONE = 1
	R11 = 2
	R13 = 3
	R2A = 4
	R2B = 5
	R3 = 6
	R4A = 7
	R4B = 8
	R5 = 9
	R7 = 10
	ZERO = 11


# noinspection SpellCheckingInspection
class ItemType(Enum):
	"""6 Members, FILLer ... WAVeform"""
	FILLer = 0
	LOOP = 1
	OVL = 2
	PULSe = 3
	SUBSequence = 4
	WAVeform = 5


# noinspection SpellCheckingInspection
class ItemTypeB(Enum):
	"""3 Members, PATTern ... USER"""
	PATTern = 0
	PRBS = 1
	USER = 2


# noinspection SpellCheckingInspection
class Lattice(Enum):
	"""2 Members, RECTangular ... TRIangular"""
	RECTangular = 0
	TRIangular = 1


# noinspection SpellCheckingInspection
class LobesCount(Enum):
	"""2 Members, _2 ... _4"""
	_2 = 0
	_4 = 1


# noinspection SpellCheckingInspection
class LoopType(Enum):
	"""2 Members, FIXed ... VARiable"""
	FIXed = 0
	VARiable = 1


# noinspection SpellCheckingInspection
class LswDirection(Enum):
	"""2 Members, H ... V"""
	H = 0
	V = 1


# noinspection SpellCheckingInspection
class ModuleType(Enum):
	"""3 Members, IPM ... REPort"""
	IPM = 0
	MOP = 1
	REPort = 2


# noinspection SpellCheckingInspection
class MopType(Enum):
	"""21 Members, AM ... QPSK"""
	AM = 0
	AMSTep = 1
	ASK = 2
	BARKer = 3
	BPSK = 4
	CCHiprp = 5
	CHIRp = 6
	FM = 7
	FMSTep = 8
	FSK = 9
	MSK = 10
	NLCHirp = 11
	NOISe = 12
	PCHirp = 13
	PLISt = 14
	PLUGin = 15
	POLYphase = 16
	PSK8 = 17
	PWISechirp = 18
	QAM = 19
	QPSK = 20


# noinspection SpellCheckingInspection
class MovementRframe(Enum):
	"""2 Members, PZ ... WGS"""
	PZ = 0
	WGS = 1


# noinspection SpellCheckingInspection
class MovementRmode(Enum):
	"""3 Members, CYCLic ... ROUNdtrip"""
	CYCLic = 0
	ONEWay = 1
	ROUNdtrip = 2


# noinspection SpellCheckingInspection
class MovementType(Enum):
	"""4 Members, ARC ... WAYPoint"""
	ARC = 0
	LINE = 1
	TRACe = 2
	WAYPoint = 3


# noinspection SpellCheckingInspection
class OutFormat(Enum):
	"""3 Members, ESEQencing ... WV"""
	ESEQencing = 0
	MSW = 1
	WV = 2


# noinspection SpellCheckingInspection
class PhaseMode(Enum):
	"""3 Members, ABSolute ... MEMory"""
	ABSolute = 0
	CONTinuous = 1
	MEMory = 2


# noinspection SpellCheckingInspection
class Pmode(Enum):
	"""2 Members, MOVing ... STATic"""
	MOVing = 0
	STATic = 1


# noinspection SpellCheckingInspection
class PmodeLocation(Enum):
	"""3 Members, MOVing ... STEPs"""
	MOVing = 0
	STATic = 1
	STEPs = 2


# noinspection SpellCheckingInspection
class PmodSource(Enum):
	"""3 Members, EXTernal ... OFF"""
	EXTernal = 0
	INTernal = 1
	OFF = 2


# noinspection SpellCheckingInspection
class PolarCut(Enum):
	"""2 Members, XY ... YZ"""
	XY = 0
	YZ = 1


# noinspection SpellCheckingInspection
class Polarization(Enum):
	"""6 Members, CLEFt ... VERTical"""
	CLEFt = 0
	CRIGht = 1
	HORizontal = 2
	SLEFt = 3
	SRIGht = 4
	VERTical = 5


# noinspection SpellCheckingInspection
class PolarType(Enum):
	"""2 Members, CARTesian ... POLar"""
	CARTesian = 0
	POLar = 1


# noinspection SpellCheckingInspection
class PolynomType(Enum):
	"""5 Members, FRANk ... P4"""
	FRANk = 0
	P1 = 1
	P2 = 2
	P3 = 3
	P4 = 4


# noinspection SpellCheckingInspection
class PrbsType(Enum):
	"""8 Members, P11 ... P9"""
	P11 = 0
	P15 = 1
	P16 = 2
	P20 = 3
	P21 = 4
	P23 = 5
	P7 = 6
	P9 = 7


# noinspection SpellCheckingInspection
class PreviewMode(Enum):
	"""2 Members, ENVelope ... MOP"""
	ENVelope = 0
	MOP = 1


# noinspection SpellCheckingInspection
class PreviewMop(Enum):
	"""3 Members, FREQuency ... PHASe"""
	FREQuency = 0
	IQ = 1
	PHASe = 2


# noinspection SpellCheckingInspection
class Psec(Enum):
	"""18 Members, NONE ... SEC9"""
	NONE = 0
	PRIMary = 1
	SEC1 = 2
	SEC10 = 3
	SEC11 = 4
	SEC12 = 5
	SEC13 = 6
	SEC14 = 7
	SEC15 = 8
	SEC16 = 9
	SEC2 = 10
	SEC3 = 11
	SEC4 = 12
	SEC5 = 13
	SEC6 = 14
	SEC7 = 15
	SEC8 = 16
	SEC9 = 17


# noinspection SpellCheckingInspection
class PulseSetting(Enum):
	"""5 Members, GENeral ... TIMing"""
	GENeral = 0
	LEVel = 1
	MKR = 2
	MOP = 3
	TIMing = 4


# noinspection SpellCheckingInspection
class PulseType(Enum):
	"""4 Members, COSine ... SQRT"""
	COSine = 0
	LINear = 1
	RCOSine = 2
	SQRT = 3


# noinspection SpellCheckingInspection
class PwdType(Enum):
	"""4 Members, AMMos ... TEMPlate"""
	AMMos = 0
	DEFault = 1
	PLUGin = 2
	TEMPlate = 3


# noinspection SpellCheckingInspection
class QamType(Enum):
	"""5 Members, Q128 ... Q64"""
	Q128 = 0
	Q16 = 1
	Q256 = 2
	Q32 = 3
	Q64 = 4


# noinspection SpellCheckingInspection
class QpskType(Enum):
	"""6 Members, ASOQpsk ... TGSoqpsk"""
	ASOQpsk = 0
	BSOQpsk = 1
	DQPSk = 2
	NORMal = 3
	OQPSk = 4
	TGSoqpsk = 5


# noinspection SpellCheckingInspection
class RandomDistribution(Enum):
	"""3 Members, NORMal ... UNIForm"""
	NORMal = 0
	U = 1
	UNIForm = 2


# noinspection SpellCheckingInspection
class RasterDirection(Enum):
	"""2 Members, HORizontal ... VERTical"""
	HORizontal = 0
	VERTical = 1


# noinspection SpellCheckingInspection
class RecModel(Enum):
	"""2 Members, INTerfero ... TDOA"""
	INTerfero = 0
	TDOA = 1


# noinspection SpellCheckingInspection
class RepeatMode(Enum):
	"""2 Members, CONTinuous ... SINGle"""
	CONTinuous = 0
	SINGle = 1


# noinspection SpellCheckingInspection
class RepetitionType(Enum):
	"""3 Members, DURation ... VARiable"""
	DURation = 0
	FIXed = 1
	VARiable = 2


# noinspection SpellCheckingInspection
class Rotation(Enum):
	"""2 Members, CCW ... CW"""
	CCW = 0
	CW = 1


# noinspection SpellCheckingInspection
class SanitizeScenario(Enum):
	"""3 Members, ALL ... SCENario"""
	ALL = 0
	REPository = 1
	SCENario = 2


# noinspection SpellCheckingInspection
class ScanType(Enum):
	"""10 Members, CIRCular ... SPIRal"""
	CIRCular = 0
	CONical = 1
	CUSTom = 2
	HELical = 3
	LISSajous = 4
	LSW = 5
	RASTer = 6
	SECTor = 7
	SIN = 8
	SPIRal = 9


# noinspection SpellCheckingInspection
class ScenarioType(Enum):
	"""9 Members, CEMitter ... WAVeform"""
	CEMitter = 0
	CSEQuence = 1
	DF = 2
	DYNamic = 3
	EMITter = 4
	LOCalized = 5
	PDW = 6
	SEQuence = 7
	WAVeform = 8


# noinspection SpellCheckingInspection
class SecurityLevel(Enum):
	"""5 Members, LEV0 ... LEV4"""
	LEV0 = 0
	LEV1 = 1
	LEV2 = 2
	LEV3 = 3
	LEV4 = 4


# noinspection SpellCheckingInspection
class SequenceType(Enum):
	"""2 Members, PULSe ... WAVeform"""
	PULSe = 0
	WAVeform = 1


# noinspection SpellCheckingInspection
class SigCont(Enum):
	"""2 Members, COMM ... PULSe"""
	COMM = 0
	PULSe = 1


# noinspection SpellCheckingInspection
class SourceInt(Enum):
	"""2 Members, EXTernal ... INTernal"""
	EXTernal = 0
	INTernal = 1


# noinspection SpellCheckingInspection
class SourceType(Enum):
	"""2 Members, PROFile ... VARiable"""
	PROFile = 0
	VARiable = 1


# noinspection SpellCheckingInspection
class State(Enum):
	"""2 Members, IDLE ... RUN"""
	IDLE = 0
	RUN = 1


# noinspection SpellCheckingInspection
class TargetOut(Enum):
	"""2 Members, FILE ... INSTrument"""
	FILE = 0
	INSTrument = 1


# noinspection SpellCheckingInspection
class TargetParam(Enum):
	"""20 Members, AMDepth ... WIDTh"""
	AMDepth = 0
	AMFRequency = 1
	CDEViation = 2
	DELay = 3
	DROop = 4
	FALL = 5
	FMDeviation = 6
	FMFRequency = 7
	FREQuency = 8
	FSKDeviation = 9
	LEVel = 10
	OVERshoot = 11
	PHASe = 12
	PRF = 13
	PRI = 14
	RFRequency = 15
	RISE = 16
	RLEVel = 17
	SRATe = 18
	WIDTh = 19


# noinspection SpellCheckingInspection
class TargetType(Enum):
	"""2 Members, PARameter ... VARiable"""
	PARameter = 0
	VARiable = 1


# noinspection SpellCheckingInspection
class TimeMode(Enum):
	"""2 Members, PRF ... PRI"""
	PRF = 0
	PRI = 1


# noinspection SpellCheckingInspection
class TimeReference(Enum):
	"""3 Members, FULL ... VOLTage"""
	FULL = 0
	POWer = 1
	VOLTage = 2


# noinspection SpellCheckingInspection
class Units(Enum):
	"""6 Members, DB ... SEConds"""
	DB = 0
	DEGRees = 1
	HERTz = 2
	NONE = 3
	PERCent = 4
	SEConds = 5


# noinspection SpellCheckingInspection
class Vehicle(Enum):
	"""5 Members, AIRPlane ... STATionary"""
	AIRPlane = 0
	LVEHicle = 1
	RECeiver = 2
	SHIP = 3
	STATionary = 4


# noinspection SpellCheckingInspection
class VehicleMovement(Enum):
	"""6 Members, AIRPlane ... STATionary"""
	AIRPlane = 0
	CAR = 1
	DEFault = 2
	LVEHicle = 3
	SHIP = 4
	STATionary = 5


# noinspection SpellCheckingInspection
class ViewCount(Enum):
	"""8 Members, _100 ... _50000"""
	_100 = 0
	_1000 = 1
	_10000 = 2
	_100000 = 3
	_50 = 4
	_500 = 5
	_5000 = 6
	_50000 = 7


# noinspection SpellCheckingInspection
class ViewXode(Enum):
	"""2 Members, SAMPles ... TIME"""
	SAMPles = 0
	TIME = 1


# noinspection SpellCheckingInspection
class WaveformShape(Enum):
	"""3 Members, RAMP ... TRIangular"""
	RAMP = 0
	SINE = 1
	TRIangular = 2


# noinspection SpellCheckingInspection
class WaveformType(Enum):
	"""10 Members, AIF ... WAVeform"""
	AIF = 0
	APDW = 1
	BEMitter = 2
	CW = 3
	IQDW = 4
	MT = 5
	NOISe = 6
	PDW = 7
	USER = 8
	WAVeform = 9


# noinspection SpellCheckingInspection
class Ymode(Enum):
	"""7 Members, FREQuency ... PHASe"""
	FREQuency = 0
	IQ = 1
	MAGDb = 2
	MAGV = 3
	MAGW = 4
	PAV = 5
	PHASe = 6



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mop:
	"""Mop commands group definition. 104 total commands, 23 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mop", core, parent)

	@property
	def am(self):
		"""am commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_am'):
			from .Am import Am
			self._am = Am(self._core, self._cmd_group)
		return self._am

	@property
	def amStep(self):
		"""amStep commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_amStep'):
			from .AmStep import AmStep
			self._amStep = AmStep(self._core, self._cmd_group)
		return self._amStep

	@property
	def ask(self):
		"""ask commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_ask'):
			from .Ask import Ask
			self._ask = Ask(self._core, self._cmd_group)
		return self._ask

	@property
	def barker(self):
		"""barker commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_barker'):
			from .Barker import Barker
			self._barker = Barker(self._core, self._cmd_group)
		return self._barker

	@property
	def bpsk(self):
		"""bpsk commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_bpsk'):
			from .Bpsk import Bpsk
			self._bpsk = Bpsk(self._core, self._cmd_group)
		return self._bpsk

	@property
	def cchirp(self):
		"""cchirp commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_cchirp'):
			from .Cchirp import Cchirp
			self._cchirp = Cchirp(self._core, self._cmd_group)
		return self._cchirp

	@property
	def chirp(self):
		"""chirp commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_chirp'):
			from .Chirp import Chirp
			self._chirp = Chirp(self._core, self._cmd_group)
		return self._chirp

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._cmd_group)
		return self._data

	@property
	def exclude(self):
		"""exclude commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_exclude'):
			from .Exclude import Exclude
			self._exclude = Exclude(self._core, self._cmd_group)
		return self._exclude

	@property
	def filterPy(self):
		"""filterPy commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._cmd_group)
		return self._filterPy

	@property
	def fm(self):
		"""fm commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_fm'):
			from .Fm import Fm
			self._fm = Fm(self._core, self._cmd_group)
		return self._fm

	@property
	def fmStep(self):
		"""fmStep commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_fmStep'):
			from .FmStep import FmStep
			self._fmStep = FmStep(self._core, self._cmd_group)
		return self._fmStep

	@property
	def fsk(self):
		"""fsk commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_fsk'):
			from .Fsk import Fsk
			self._fsk = Fsk(self._core, self._cmd_group)
		return self._fsk

	@property
	def msk(self):
		"""msk commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_msk'):
			from .Msk import Msk
			self._msk = Msk(self._core, self._cmd_group)
		return self._msk

	@property
	def nlCirp(self):
		"""nlCirp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nlCirp'):
			from .NlCirp import NlCirp
			self._nlCirp = NlCirp(self._core, self._cmd_group)
		return self._nlCirp

	@property
	def noise(self):
		"""noise commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import Noise
			self._noise = Noise(self._core, self._cmd_group)
		return self._noise

	@property
	def pchirp(self):
		"""pchirp commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_pchirp'):
			from .Pchirp import Pchirp
			self._pchirp = Pchirp(self._core, self._cmd_group)
		return self._pchirp

	@property
	def piecewise(self):
		"""piecewise commands group. 1 Sub-classes, 8 commands."""
		if not hasattr(self, '_piecewise'):
			from .Piecewise import Piecewise
			self._piecewise = Piecewise(self._core, self._cmd_group)
		return self._piecewise

	@property
	def plist(self):
		"""plist commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_plist'):
			from .Plist import Plist
			self._plist = Plist(self._core, self._cmd_group)
		return self._plist

	@property
	def plugin(self):
		"""plugin commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_plugin'):
			from .Plugin import Plugin
			self._plugin = Plugin(self._core, self._cmd_group)
		return self._plugin

	@property
	def poly(self):
		"""poly commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_poly'):
			from .Poly import Poly
			self._poly = Poly(self._core, self._cmd_group)
		return self._poly

	@property
	def qam(self):
		"""qam commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_qam'):
			from .Qam import Qam
			self._qam = Qam(self._core, self._cmd_group)
		return self._qam

	@property
	def qpsk(self):
		"""qpsk commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_qpsk'):
			from .Qpsk import Qpsk
			self._qpsk = Qpsk(self._core, self._cmd_group)
		return self._qpsk

	def get_comment(self) -> str:
		"""SCPI: PULSe:MOP:COMMent \n
		Snippet: value: str = driver.pulse.mop.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('PULSe:MOP:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: PULSe:MOP:COMMent \n
		Snippet: driver.pulse.mop.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'PULSe:MOP:COMMent {param}')

	def get_enable(self) -> bool:
		"""SCPI: PULSe:MOP:ENABle \n
		Snippet: value: bool = driver.pulse.mop.get_enable() \n
		Defines whether a MOP is applied. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: PULSe:MOP:ENABle \n
		Snippet: driver.pulse.mop.set_enable(enable = False) \n
		Defines whether a MOP is applied. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'PULSe:MOP:ENABle {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.MopType:
		"""SCPI: PULSe:MOP:TYPE \n
		Snippet: value: enums.MopType = driver.pulse.mop.get_type_py() \n
		Select the modulation scheme. \n
			:return: type_py: AM| ASK| AMSTep| FM| FSK| FMSTep| CHIRp| PCHirp| BARKer| POLYphase| PLISt| BPSK| QPSK| NOISe| PWISechirp| CCHiprp| PSK8| QAM| MSK | NLCHirp| PLUGin
		"""
		response = self._core.io.query_str('PULSe:MOP:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.MopType)

	def set_type_py(self, type_py: enums.MopType) -> None:
		"""SCPI: PULSe:MOP:TYPE \n
		Snippet: driver.pulse.mop.set_type_py(type_py = enums.MopType.AM) \n
		Select the modulation scheme. \n
			:param type_py: AM| ASK| AMSTep| FM| FSK| FMSTep| CHIRp| PCHirp| BARKer| POLYphase| PLISt| BPSK| QPSK| NOISe| PWISechirp| CCHiprp| PSK8| QAM| MSK | NLCHirp| PLUGin
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MopType)
		self._core.io.write(f'PULSe:MOP:TYPE {param}')

	def clone(self) -> 'Mop':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mop(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rotation:
	"""Rotation commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rotation", core, parent)

	def get_x(self) -> float:
		"""SCPI: ANTenna:MODel:ROTation:X \n
		Snippet: value: float = driver.antenna.model.rotation.get_x() \n
		Sets the X and Z antenna rotation. \n
			:return: x: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:ROTation:X?')
		return Conversions.str_to_float(response)

	def set_x(self, x: float) -> None:
		"""SCPI: ANTenna:MODel:ROTation:X \n
		Snippet: driver.antenna.model.rotation.set_x(x = 1.0) \n
		Sets the X and Z antenna rotation. \n
			:param x: float Range: -180 to 180, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(x)
		self._core.io.write(f'ANTenna:MODel:ROTation:X {param}')

	def get_z(self) -> float:
		"""SCPI: ANTenna:MODel:ROTation:Z \n
		Snippet: value: float = driver.antenna.model.rotation.get_z() \n
		Sets the X and Z antenna rotation. \n
			:return: z: float Range: -180 to 180, Unit: degree
		"""
		response = self._core.io.query_str('ANTenna:MODel:ROTation:Z?')
		return Conversions.str_to_float(response)

	def set_z(self, z: float) -> None:
		"""SCPI: ANTenna:MODel:ROTation:Z \n
		Snippet: driver.antenna.model.rotation.set_z(z = 1.0) \n
		Sets the X and Z antenna rotation. \n
			:param z: float Range: -180 to 180, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(z)
		self._core.io.write(f'ANTenna:MODel:ROTation:Z {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Xpol:
	"""Xpol commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("xpol", core, parent)

	def get_attenuation(self) -> float:
		"""SCPI: REPository:XPOL:ATTenuation \n
		Snippet: value: float = driver.repository.xpol.get_attenuation() \n
		Sets the attenuation used to calculate the cross-polarized antenna patterns. \n
			:return: attenuation: float
		"""
		response = self._core.io.query_str('REPository:XPOL:ATTenuation?')
		return Conversions.str_to_float(response)

	def set_attenuation(self, attenuation: float) -> None:
		"""SCPI: REPository:XPOL:ATTenuation \n
		Snippet: driver.repository.xpol.set_attenuation(attenuation = 1.0) \n
		Sets the attenuation used to calculate the cross-polarized antenna patterns. \n
			:param attenuation: float
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'REPository:XPOL:ATTenuation {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Emitter:
	"""Emitter commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emitter", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def clear(self) -> None:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:CLEar \n
		Snippet: driver.assignment.generator.path.emitter.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'ASSignment:GENerator:PATH:EMITter:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:CLEar \n
		Snippet: driver.assignment.generator.path.emitter.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ASSignment:GENerator:PATH:EMITter:CLEar', opc_timeout_ms)

	def delete(self) -> None:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:DELete \n
		Snippet: driver.assignment.generator.path.emitter.delete() \n
		Deletes the particular item. \n
		"""
		self._core.io.write(f'ASSignment:GENerator:PATH:EMITter:DELete')

	def delete_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:DELete \n
		Snippet: driver.assignment.generator.path.emitter.delete_with_opc() \n
		Deletes the particular item. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ASSignment:GENerator:PATH:EMITter:DELete', opc_timeout_ms)

	def get_list_py(self) -> str:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:LIST \n
		Snippet: value: str = driver.assignment.generator.path.emitter.get_list_py() \n
		Queries the list of assigned emitters/interferes to the selected path. \n
			:return: list_py: 'Emitter/Inter#1','Emitter/Inter#2',...
		"""
		response = self._core.io.query_str('ASSignment:GENerator:PATH:EMITter:LIST?')
		return trim_str_response(response)

	def get_select(self) -> str:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:SELect \n
		Snippet: value: str = driver.assignment.generator.path.emitter.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('ASSignment:GENerator:PATH:EMITter:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: ASSignment:GENerator:PATH:EMITter:SELect \n
		Snippet: driver.assignment.generator.path.emitter.set_select(select = '1') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'ASSignment:GENerator:PATH:EMITter:SELect {param}')

	def clone(self) -> 'Emitter':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Emitter(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Am:
	"""Am commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("am", core, parent)

	def get_depth(self) -> float:
		"""SCPI: IMPort:PDW:DATA:AM:DEPTh \n
		Snippet: value: float = driver.importPy.pdw.data.am.get_depth() \n
		Queries the pulse parameter. \n
			:return: depth: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:AM:DEPTh?')
		return Conversions.str_to_float(response)

	def get_mod_freq(self) -> float:
		"""SCPI: IMPort:PDW:DATA:AM:MODFreq \n
		Snippet: value: float = driver.importPy.pdw.data.am.get_mod_freq() \n
		Queries the pulse parameter. \n
			:return: mod_freq: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:AM:MODFreq?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Details:
	"""Details commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("details", core, parent)

	def get_albs(self) -> bool:
		"""SCPI: SCENario:OUTPut:ARB:DETails:ALBS \n
		Snippet: value: bool = driver.scenario.output.arb.details.get_albs() \n
		Enables you to calculate the antenna attenuation for each sample. Otherwise a lookup at center position is used. \n
			:return: albs: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:OUTPut:ARB:DETails:ALBS?')
		return Conversions.str_to_bool(response)

	def set_albs(self, albs: bool) -> None:
		"""SCPI: SCENario:OUTPut:ARB:DETails:ALBS \n
		Snippet: driver.scenario.output.arb.details.set_albs(albs = False) \n
		Enables you to calculate the antenna attenuation for each sample. Otherwise a lookup at center position is used. \n
			:param albs: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(albs)
		self._core.io.write(f'SCENario:OUTPut:ARB:DETails:ALBS {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HigHq:
	"""HigHq commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("higHq", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SETup:HIGHq:ENABle \n
		Snippet: value: bool = driver.setup.higHq.get_enable() \n
		Sets the I/Q modulator of signal generator to work in a high quality mode. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SETup:HIGHq:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SETup:HIGHq:ENABle \n
		Snippet: driver.setup.higHq.set_enable(enable = False) \n
		Sets the I/Q modulator of signal generator to work in a high quality mode. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SETup:HIGHq:ENABle {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.HqMode:
		"""SCPI: SETup:HIGHq:MODE \n
		Snippet: value: enums.HqMode = driver.setup.higHq.get_mode() \n
		Defines which high-quality mode is used. Requires that method RsPulseSeq.Setup.HigHq.enable is set to ON (see method
		RsPulseSeq.Setup.HigHq.enable) . \n
			:return: mode: NORMal| TABLe NORM Enables compensation for I/Q skew and frequency response correction. This mode generates a flat signal over a large bandwidth but requires longer setting time and can lead to signal interruption. TABL This mode provides optimization while maintaining settling time.
		"""
		response = self._core.io.query_str('SETup:HIGHq:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.HqMode)

	def set_mode(self, mode: enums.HqMode) -> None:
		"""SCPI: SETup:HIGHq:MODE \n
		Snippet: driver.setup.higHq.set_mode(mode = enums.HqMode.NORMal) \n
		Defines which high-quality mode is used. Requires that method RsPulseSeq.Setup.HigHq.enable is set to ON (see method
		RsPulseSeq.Setup.HigHq.enable) . \n
			:param mode: NORMal| TABLe NORM Enables compensation for I/Q skew and frequency response correction. This mode generates a flat signal over a large bandwidth but requires longer setting time and can lead to signal interruption. TABL This mode provides optimization while maintaining settling time.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.HqMode)
		self._core.io.write(f'SETup:HIGHq:MODE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRate:
	"""SymbolRate commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def get_auto(self) -> bool:
		"""SCPI: PULSe:MOP:BPSK:SRATe:AUTO \n
		Snippet: value: bool = driver.pulse.mop.bpsk.symbolRate.get_auto() \n
		Enables automatic adjusting of the bits in the pulse width. \n
			:return: auto: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:SRATe:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, auto: bool) -> None:
		"""SCPI: PULSe:MOP:BPSK:SRATe:AUTO \n
		Snippet: driver.pulse.mop.bpsk.symbolRate.set_auto(auto = False) \n
		Enables automatic adjusting of the bits in the pulse width. \n
			:param auto: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(auto)
		self._core.io.write(f'PULSe:MOP:BPSK:SRATe:AUTO {param}')

	def get_value(self) -> float:
		"""SCPI: PULSe:MOP:BPSK:SRATe \n
		Snippet: value: float = driver.pulse.mop.bpsk.symbolRate.get_value() \n
		Sets the symbol rate. \n
			:return: srate: float Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:SRATe?')
		return Conversions.str_to_float(response)

	def set_value(self, srate: float) -> None:
		"""SCPI: PULSe:MOP:BPSK:SRATe \n
		Snippet: driver.pulse.mop.bpsk.symbolRate.set_value(srate = 1.0) \n
		Sets the symbol rate. \n
			:param srate: float Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'PULSe:MOP:BPSK:SRATe {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Preview:
	"""Preview commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("preview", core, parent)

	def set_mode(self, mode: enums.PreviewMode) -> None:
		"""SCPI: PULSe:PREView:MODE \n
		Snippet: driver.pulse.preview.set_mode(mode = enums.PreviewMode.ENVelope) \n
		Switches between the envelope and modulation graphs. \n
			:param mode: ENVelope| MOP
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PreviewMode)
		self._core.io.write(f'PULSe:PREView:MODE {param}')

	def set_mop(self, mop: enums.PreviewMop) -> None:
		"""SCPI: PULSe:PREView:MOP \n
		Snippet: driver.pulse.preview.set_mop(mop = enums.PreviewMop.FREQuency) \n
		Sets the displayed modulation characteristics. \n
			:param mop: IQ| PHASe| FREQuency
		"""
		param = Conversions.enum_scalar_to_str(mop, enums.PreviewMop)
		self._core.io.write(f'PULSe:PREView:MOP {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Duration:
	"""Duration commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("duration", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AutoManualMode:
		"""SCPI: SCENario:OUTPut:DURation:MODE \n
		Snippet: value: enums.AutoManualMode = driver.scenario.output.duration.get_mode() \n
		Sets how the waveform duration is defined. \n
			:return: mode: AUTO| MANual
		"""
		response = self._core.io.query_str('SCENario:OUTPut:DURation:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_mode(self, mode: enums.AutoManualMode) -> None:
		"""SCPI: SCENario:OUTPut:DURation:MODE \n
		Snippet: driver.scenario.output.duration.set_mode(mode = enums.AutoManualMode.AUTO) \n
		Sets how the waveform duration is defined. \n
			:param mode: AUTO| MANual
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
		self._core.io.write(f'SCENario:OUTPut:DURation:MODE {param}')

	def get_time(self) -> float:
		"""SCPI: SCENario:OUTPut:DURation:TIME \n
		Snippet: value: float = driver.scenario.output.duration.get_time() \n
		Sets the duration of the generated waveform. \n
			:return: time: float Range: 1e-06 to 1.8432e+06 Simulation time longer than 7200s requires R&S SMW with firmware version 5.xx.xxx and higher. To query the installed firmware version of the selected instrument, use the command method RsPulseSeq.Instrument.firmware.
		"""
		response = self._core.io.query_str('SCENario:OUTPut:DURation:TIME?')
		return Conversions.str_to_float(response)

	def set_time(self, time: float) -> None:
		"""SCPI: SCENario:OUTPut:DURation:TIME \n
		Snippet: driver.scenario.output.duration.set_time(time = 1.0) \n
		Sets the duration of the generated waveform. \n
			:param time: float Range: 1e-06 to 1.8432e+06 Simulation time longer than 7200s requires R&S SMW with firmware version 5.xx.xxx and higher. To query the installed firmware version of the selected instrument, use the command method RsPulseSeq.Instrument.firmware.
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SCENario:OUTPut:DURation:TIME {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 34 total commands, 9 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def am(self):
		"""am commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_am'):
			from .Am import Am
			self._am = Am(self._core, self._cmd_group)
		return self._am

	@property
	def ask(self):
		"""ask commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_ask'):
			from .Ask import Ask
			self._ask = Ask(self._core, self._cmd_group)
		return self._ask

	@property
	def cph(self):
		"""cph commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_cph'):
			from .Cph import Cph
			self._cph = Cph(self._core, self._cmd_group)
		return self._cph

	@property
	def fm(self):
		"""fm commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_fm'):
			from .Fm import Fm
			self._fm = Fm(self._core, self._cmd_group)
		return self._fm

	@property
	def fsk(self):
		"""fsk commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_fsk'):
			from .Fsk import Fsk
			self._fsk = Fsk(self._core, self._cmd_group)
		return self._fsk

	@property
	def lfm(self):
		"""lfm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lfm'):
			from .Lfm import Lfm
			self._lfm = Lfm(self._core, self._cmd_group)
		return self._lfm

	@property
	def nlFm(self):
		"""nlFm commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_nlFm'):
			from .NlFm import NlFm
			self._nlFm = NlFm(self._core, self._cmd_group)
		return self._nlFm

	@property
	def plFm(self):
		"""plFm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_plFm'):
			from .PlFm import PlFm
			self._plFm = PlFm(self._core, self._cmd_group)
		return self._plFm

	@property
	def psk(self):
		"""psk commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_psk'):
			from .Psk import Psk
			self._psk = Psk(self._core, self._cmd_group)
		return self._psk

	def get_frequency(self) -> float:
		"""SCPI: IMPort:PDW:DATA:FREQuency \n
		Snippet: value: float = driver.importPy.pdw.data.get_frequency() \n
		Queries the pulse parameter. \n
			:return: frequency: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:FREQuency?')
		return Conversions.str_to_float(response)

	def get_level(self) -> float:
		"""SCPI: IMPort:PDW:DATA:LEVel \n
		Snippet: value: float = driver.importPy.pdw.data.get_level() \n
		Queries the pulse parameter. \n
			:return: level: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:LEVel?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_mop(self) -> enums.DataMop:
		"""SCPI: IMPort:PDW:DATA:MOP \n
		Snippet: value: enums.DataMop = driver.importPy.pdw.data.get_mop() \n
		Queries the used modulation on pulse (MOP) . Use the corresponding command to query further pulse and modulation
		parameter for the respective MOP. \n
			:return: mop: CW| AM| FM| ASK| FSK| PSK| LFM| NLFM| TFM| BKR2a| BKR2b| BKR3| BKR4a| BKR4b| BKR5| BKR7| BKR11| BKR13| CPH| PLFM
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:MOP?')
		return Conversions.str_to_scalar_enum(response, enums.DataMop)

	def get_offset(self) -> float:
		"""SCPI: IMPort:PDW:DATA:OFFSet \n
		Snippet: value: float = driver.importPy.pdw.data.get_offset() \n
		Queries the pulse parameter. \n
			:return: offset: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:OFFSet?')
		return Conversions.str_to_float(response)

	def get_phase(self) -> float:
		"""SCPI: IMPort:PDW:DATA:PHASe \n
		Snippet: value: float = driver.importPy.pdw.data.get_phase() \n
		Queries the pulse parameter. \n
			:return: phase: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PHASe?')
		return Conversions.str_to_float(response)

	def get_sel(self) -> float:
		"""SCPI: IMPort:PDW:DATA:SEL \n
		Snippet: value: float = driver.importPy.pdw.data.get_sel() \n
		Selects the pulse for that the further queries apply. \n
			:return: sel: float Range: 1 to max
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:SEL?')
		return Conversions.str_to_float(response)

	def set_sel(self, sel: float) -> None:
		"""SCPI: IMPort:PDW:DATA:SEL \n
		Snippet: driver.importPy.pdw.data.set_sel(sel = 1.0) \n
		Selects the pulse for that the further queries apply. \n
			:param sel: float Range: 1 to max
		"""
		param = Conversions.decimal_value_to_str(sel)
		self._core.io.write(f'IMPort:PDW:DATA:SEL {param}')

	def get_toa(self) -> float:
		"""SCPI: IMPort:PDW:DATA:TOA \n
		Snippet: value: float = driver.importPy.pdw.data.get_toa() \n
		Queries the pulse parameter. \n
			:return: toa: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:TOA?')
		return Conversions.str_to_float(response)

	def get_width(self) -> float:
		"""SCPI: IMPort:PDW:DATA:WIDTh \n
		Snippet: value: float = driver.importPy.pdw.data.get_width() \n
		Queries the pulse parameter. \n
			:return: width: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:WIDTh?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdw:
	"""Pdw commands group definition. 44 total commands, 4 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdw", core, parent)

	@property
	def data(self):
		"""data commands group. 9 Sub-classes, 8 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._cmd_group)
		return self._data

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._cmd_group)
		return self._execute

	@property
	def file(self):
		"""file commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import File
			self._file = File(self._core, self._cmd_group)
		return self._file

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import Store
			self._store = Store(self._core, self._cmd_group)
		return self._store

	def get_norm(self) -> bool:
		"""SCPI: IMPort:PDW:NORM \n
		Snippet: value: bool = driver.importPy.pdw.get_norm() \n
		Normalizes the TOA (time of arrival) of the first pulse to 0. Subsequent TOAs are relative. \n
			:return: norm: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('IMPort:PDW:NORM?')
		return Conversions.str_to_bool(response)

	def set_norm(self, norm: bool) -> None:
		"""SCPI: IMPort:PDW:NORM \n
		Snippet: driver.importPy.pdw.set_norm(norm = False) \n
		Normalizes the TOA (time of arrival) of the first pulse to 0. Subsequent TOAs are relative. \n
			:param norm: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(norm)
		self._core.io.write(f'IMPort:PDW:NORM {param}')

	def get_status(self) -> bool:
		"""SCPI: IMPort:PDW:STATus \n
		Snippet: value: bool = driver.importPy.pdw.get_status() \n
		Queries the parsing status. \n
			:return: status: ON| OFF| 1| 0 1 Import completed
		"""
		response = self._core.io.query_str('IMPort:PDW:STATus?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'Pdw':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pdw(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rstep:
	"""Rstep commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rstep", core, parent)

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._cmd_group)
		return self._step

	def get_maximum(self) -> float:
		"""SCPI: IPM:RSTep:MAXimum \n
		Snippet: value: float = driver.ipm.rstep.get_maximum() \n
		Sets the value range. \n
			:return: maximum: float Range: 0 to 1e+11
		"""
		response = self._core.io.query_str('IPM:RSTep:MAXimum?')
		return Conversions.str_to_float(response)

	def set_maximum(self, maximum: float) -> None:
		"""SCPI: IPM:RSTep:MAXimum \n
		Snippet: driver.ipm.rstep.set_maximum(maximum = 1.0) \n
		Sets the value range. \n
			:param maximum: float Range: 0 to 1e+11
		"""
		param = Conversions.decimal_value_to_str(maximum)
		self._core.io.write(f'IPM:RSTep:MAXimum {param}')

	def get_minimum(self) -> float:
		"""SCPI: IPM:RSTep:MINimum \n
		Snippet: value: float = driver.ipm.rstep.get_minimum() \n
		Sets the value range. \n
			:return: minimum: No help available
		"""
		response = self._core.io.query_str('IPM:RSTep:MINimum?')
		return Conversions.str_to_float(response)

	def set_minimum(self, minimum: float) -> None:
		"""SCPI: IPM:RSTep:MINimum \n
		Snippet: driver.ipm.rstep.set_minimum(minimum = 1.0) \n
		Sets the value range. \n
			:param minimum: float Range: 0 to 1e+11
		"""
		param = Conversions.decimal_value_to_str(minimum)
		self._core.io.write(f'IPM:RSTep:MINimum {param}')

	def get_period(self) -> float:
		"""SCPI: IPM:RSTep:PERiod \n
		Snippet: value: float = driver.ipm.rstep.get_period() \n
		Sets the pattern length. \n
			:return: period: float Range: 0 to 4096
		"""
		response = self._core.io.query_str('IPM:RSTep:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: IPM:RSTep:PERiod \n
		Snippet: driver.ipm.rstep.set_period(period = 1.0) \n
		Sets the pattern length. \n
			:param period: float Range: 0 to 4096
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'IPM:RSTep:PERiod {param}')

	def clone(self) -> 'Rstep':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rstep(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Circular:
	"""Circular commands group definition. 10 total commands, 0 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("circular", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.CircularMode:
		"""SCPI: SCAN:CIRCular:MODE \n
		Snippet: value: enums.CircularMode = driver.scan.circular.get_mode() \n
		Sets if the scan turning speed is set as a scans rate or as a period. \n
			:return: mode: RPM| SEC RPM Scan rate, set with the command method RsPulseSeq.Scan.Circular.rpm. SEC Scan period, set with the command method RsPulseSeq.Scan.Circular.period.
		"""
		response = self._core.io.query_str('SCAN:CIRCular:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.CircularMode)

	def set_mode(self, mode: enums.CircularMode) -> None:
		"""SCPI: SCAN:CIRCular:MODE \n
		Snippet: driver.scan.circular.set_mode(mode = enums.CircularMode.RPM) \n
		Sets if the scan turning speed is set as a scans rate or as a period. \n
			:param mode: RPM| SEC RPM Scan rate, set with the command method RsPulseSeq.Scan.Circular.rpm. SEC Scan period, set with the command method RsPulseSeq.Scan.Circular.period.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.CircularMode)
		self._core.io.write(f'SCAN:CIRCular:MODE {param}')

	def get_nelevation(self) -> float:
		"""SCPI: SCAN:CIRCular:NELevation \n
		Snippet: value: float = driver.scan.circular.get_nelevation() \n
		Sets the elevation angle. \n
			:return: nelevation: float Range: 0.01 to 90
		"""
		response = self._core.io.query_str('SCAN:CIRCular:NELevation?')
		return Conversions.str_to_float(response)

	def set_nelevation(self, nelevation: float) -> None:
		"""SCPI: SCAN:CIRCular:NELevation \n
		Snippet: driver.scan.circular.set_nelevation(nelevation = 1.0) \n
		Sets the elevation angle. \n
			:param nelevation: float Range: 0.01 to 90
		"""
		param = Conversions.decimal_value_to_str(nelevation)
		self._core.io.write(f'SCAN:CIRCular:NELevation {param}')

	def get_nodding(self) -> bool:
		"""SCPI: SCAN:CIRCular:NODDing \n
		Snippet: value: bool = driver.scan.circular.get_nodding() \n
		Enables superimposing a horizontal nodding on the scan. \n
			:return: nodding: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:CIRCular:NODDing?')
		return Conversions.str_to_bool(response)

	def set_nodding(self, nodding: bool) -> None:
		"""SCPI: SCAN:CIRCular:NODDing \n
		Snippet: driver.scan.circular.set_nodding(nodding = False) \n
		Enables superimposing a horizontal nodding on the scan. \n
			:param nodding: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(nodding)
		self._core.io.write(f'SCAN:CIRCular:NODDing {param}')

	def get_nrate(self) -> float:
		"""SCPI: SCAN:CIRCular:NRATe \n
		Snippet: value: float = driver.scan.circular.get_nrate() \n
		Sets the elevation rate. \n
			:return: nrate: float Range: 0.01 to 2000
		"""
		response = self._core.io.query_str('SCAN:CIRCular:NRATe?')
		return Conversions.str_to_float(response)

	def set_nrate(self, nrate: float) -> None:
		"""SCPI: SCAN:CIRCular:NRATe \n
		Snippet: driver.scan.circular.set_nrate(nrate = 1.0) \n
		Sets the elevation rate. \n
			:param nrate: float Range: 0.01 to 2000
		"""
		param = Conversions.decimal_value_to_str(nrate)
		self._core.io.write(f'SCAN:CIRCular:NRATe {param}')

	def get_palmer(self) -> bool:
		"""SCPI: SCAN:CIRCular:PALMer \n
		Snippet: value: bool = driver.scan.circular.get_palmer() \n
		Enables superimposing a conical scan on the current scan. \n
			:return: palmer: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:CIRCular:PALMer?')
		return Conversions.str_to_bool(response)

	def set_palmer(self, palmer: bool) -> None:
		"""SCPI: SCAN:CIRCular:PALMer \n
		Snippet: driver.scan.circular.set_palmer(palmer = False) \n
		Enables superimposing a conical scan on the current scan. \n
			:param palmer: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(palmer)
		self._core.io.write(f'SCAN:CIRCular:PALMer {param}')

	def get_period(self) -> float:
		"""SCPI: SCAN:CIRCular:PERiod \n
		Snippet: value: float = driver.scan.circular.get_period() \n
		Sets the time it takes for the antenna to turn once. \n
			:return: period: float Range: 0.006 to 6000
		"""
		response = self._core.io.query_str('SCAN:CIRCular:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: SCAN:CIRCular:PERiod \n
		Snippet: driver.scan.circular.set_period(period = 1.0) \n
		Sets the time it takes for the antenna to turn once. \n
			:param period: float Range: 0.006 to 6000
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'SCAN:CIRCular:PERiod {param}')

	def get_prate(self) -> float:
		"""SCPI: SCAN:CIRCular:PRATe \n
		Snippet: value: float = driver.scan.circular.get_prate() \n
		Sets the scan rate. \n
			:return: prate: float Range: 0.1 to 1000
		"""
		response = self._core.io.query_str('SCAN:CIRCular:PRATe?')
		return Conversions.str_to_float(response)

	def set_prate(self, prate: float) -> None:
		"""SCPI: SCAN:CIRCular:PRATe \n
		Snippet: driver.scan.circular.set_prate(prate = 1.0) \n
		Sets the scan rate. \n
			:param prate: float Range: 0.1 to 1000
		"""
		param = Conversions.decimal_value_to_str(prate)
		self._core.io.write(f'SCAN:CIRCular:PRATe {param}')

	def get_psquint(self) -> float:
		"""SCPI: SCAN:CIRCular:PSQuint \n
		Snippet: value: float = driver.scan.circular.get_psquint() \n
		Sets the squint angle. \n
			:return: psquint: float Range: 0.05 to 45
		"""
		response = self._core.io.query_str('SCAN:CIRCular:PSQuint?')
		return Conversions.str_to_float(response)

	def set_psquint(self, psquint: float) -> None:
		"""SCPI: SCAN:CIRCular:PSQuint \n
		Snippet: driver.scan.circular.set_psquint(psquint = 1.0) \n
		Sets the squint angle. \n
			:param psquint: float Range: 0.05 to 45
		"""
		param = Conversions.decimal_value_to_str(psquint)
		self._core.io.write(f'SCAN:CIRCular:PSQuint {param}')

	# noinspection PyTypeChecker
	def get_rotation(self) -> enums.Rotation:
		"""SCPI: SCAN:CIRCular:ROTation \n
		Snippet: value: enums.Rotation = driver.scan.circular.get_rotation() \n
		Sets the rotation direction of the antenna. \n
			:return: rotation: CW| CCW
		"""
		response = self._core.io.query_str('SCAN:CIRCular:ROTation?')
		return Conversions.str_to_scalar_enum(response, enums.Rotation)

	def set_rotation(self, rotation: enums.Rotation) -> None:
		"""SCPI: SCAN:CIRCular:ROTation \n
		Snippet: driver.scan.circular.set_rotation(rotation = enums.Rotation.CCW) \n
		Sets the rotation direction of the antenna. \n
			:param rotation: CW| CCW
		"""
		param = Conversions.enum_scalar_to_str(rotation, enums.Rotation)
		self._core.io.write(f'SCAN:CIRCular:ROTation {param}')

	def get_rpm(self) -> float:
		"""SCPI: SCAN:CIRCular:RPM \n
		Snippet: value: float = driver.scan.circular.get_rpm() \n
		Sets the rotation speed of the antenna. \n
			:return: rpm: float Range: 0.01 to 1000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:CIRCular:RPM?')
		return Conversions.str_to_float(response)

	def set_rpm(self, rpm: float) -> None:
		"""SCPI: SCAN:CIRCular:RPM \n
		Snippet: driver.scan.circular.set_rpm(rpm = 1.0) \n
		Sets the rotation speed of the antenna. \n
			:param rpm: float Range: 0.01 to 1000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rpm)
		self._core.io.write(f'SCAN:CIRCular:RPM {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StorageLoc:
	"""StorageLoc commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("storageLoc", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: PROGram:STORageloc:ENABle \n
		Snippet: value: bool = driver.program.storageLoc.get_enable() \n
		If enabled, you can select the directory in that new repository is saved. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PROGram:STORageloc:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: PROGram:STORageloc:ENABle \n
		Snippet: driver.program.storageLoc.set_enable(enable = False) \n
		If enabled, you can select the directory in that new repository is saved. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'PROGram:STORageloc:ENABle {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Move:
	"""Move commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("move", core, parent)

	@property
	def backwards(self):
		"""backwards commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_backwards'):
			from .Backwards import Backwards
			self._backwards = Backwards(self._core, self._cmd_group)
		return self._backwards

	@property
	def end(self):
		"""end commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_end'):
			from .End import End
			self._end = End(self._core, self._cmd_group)
		return self._end

	@property
	def forward(self):
		"""forward commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_forward'):
			from .Forward import Forward
			self._forward = Forward(self._core, self._cmd_group)
		return self._forward

	def start(self) -> None:
		"""SCPI: IMPort:VIEW:MOVE:STARt \n
		Snippet: driver.importPy.view.move.start() \n
		Goes to the first/next/previous/last page. \n
		"""
		self._core.io.write(f'IMPort:VIEW:MOVE:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: IMPort:VIEW:MOVE:STARt \n
		Snippet: driver.importPy.view.move.start_with_opc() \n
		Goes to the first/next/previous/last page. \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'IMPort:VIEW:MOVE:STARt', opc_timeout_ms)

	def clone(self) -> 'Move':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Move(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfAlign:
	"""RfAlign commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rfAlign", core, parent)

	@property
	def importPy(self):
		"""importPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_importPy'):
			from .ImportPy import ImportPy
			self._importPy = ImportPy(self._core, self._cmd_group)
		return self._importPy

	def get_instrument(self) -> str:
		"""SCPI: SETup:RFALign:INSTrument \n
		Snippet: value: str = driver.setup.rfAlign.get_instrument() \n
		Selects the instrument or computer from that the RF port alignment setup file is loaded. \n
			:return: instrument: string IP address or the hostname
		"""
		response = self._core.io.query_str('SETup:RFALign:INSTrument?')
		return trim_str_response(response)

	def set_instrument(self, instrument: str) -> None:
		"""SCPI: SETup:RFALign:INSTrument \n
		Snippet: driver.setup.rfAlign.set_instrument(instrument = '1') \n
		Selects the instrument or computer from that the RF port alignment setup file is loaded. \n
			:param instrument: string IP address or the hostname
		"""
		param = Conversions.value_to_quoted_str(instrument)
		self._core.io.write(f'SETup:RFALign:INSTrument {param}')

	def get_setup(self) -> str:
		"""SCPI: SETup:RFALign:SETup \n
		Snippet: value: str = driver.setup.rfAlign.get_setup() \n
		Selects the setup file to be laded. Setup files are files with predefined file format, content and the extension *.rfsa.
		For details, see the user manual of the corresponding base unit. \n
			:return: setup: string Complete file path with file name, incl. file extension
		"""
		response = self._core.io.query_str('SETup:RFALign:SETup?')
		return trim_str_response(response)

	def set_setup(self, setup: str) -> None:
		"""SCPI: SETup:RFALign:SETup \n
		Snippet: driver.setup.rfAlign.set_setup(setup = '1') \n
		Selects the setup file to be laded. Setup files are files with predefined file format, content and the extension *.rfsa.
		For details, see the user manual of the corresponding base unit. \n
			:param setup: string Complete file path with file name, incl. file extension
		"""
		param = Conversions.value_to_quoted_str(setup)
		self._core.io.write(f'SETup:RFALign:SETup {param}')

	def clone(self) -> 'RfAlign':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfAlign(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pstep:
	"""Pstep commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pstep", core, parent)

	def get_select(self) -> float:
		"""SCPI: SCENario:DF:RECeiver:MOVement:PSTep:SELect \n
		Snippet: value: float = driver.scenario.df.receiver.movement.pstep.get_select() \n
		Selects the specified point on a trace trajectory. \n
			:return: select: float
		"""
		response = self._core.io.query_str('SCENario:DF:RECeiver:MOVement:PSTep:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCENario:DF:RECeiver:MOVement:PSTep:SELect \n
		Snippet: driver.scenario.df.receiver.movement.pstep.set_select(select = 1.0) \n
		Selects the specified point on a trace trajectory. \n
			:param select: float
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCENario:DF:RECeiver:MOVement:PSTep:SELect {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from ..Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsgLog:
	"""MsgLog commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("msgLog", core, parent)

	def get_error(self) -> str:
		"""SCPI: MSGLog:ERRor \n
		Snippet: value: str = driver.msgLog.get_error() \n
		Queries the last error listed in the 'Message Log' dialog. \n
			:return: error: string
		"""
		response = self._core.io.query_str('MSGLog:ERRor?')
		return trim_str_response(response)

	def get_popup(self) -> bool:
		"""SCPI: MSGLog:POPup \n
		Snippet: value: bool = driver.msgLog.get_popup() \n
		Opens/closes the 'Message Log' dialog. \n
			:return: popup: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('MSGLog:POPup?')
		return Conversions.str_to_bool(response)

	def set_popup(self, popup: bool) -> None:
		"""SCPI: MSGLog:POPup \n
		Snippet: driver.msgLog.set_popup(popup = False) \n
		Opens/closes the 'Message Log' dialog. \n
			:param popup: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(popup)
		self._core.io.write(f'MSGLog:POPup {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mt:
	"""Mt commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mt", core, parent)

	def get_count(self) -> float:
		"""SCPI: WAVeform:MT:COUNt \n
		Snippet: value: float = driver.waveform.mt.get_count() \n
		Sets the number of tones. \n
			:return: count: integer Range: 2 to 1024
		"""
		response = self._core.io.query_str('WAVeform:MT:COUNt?')
		return Conversions.str_to_float(response)

	def set_count(self, count: float) -> None:
		"""SCPI: WAVeform:MT:COUNt \n
		Snippet: driver.waveform.mt.set_count(count = 1.0) \n
		Sets the number of tones. \n
			:param count: integer Range: 2 to 1024
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'WAVeform:MT:COUNt {param}')

	def get_spacing(self) -> float:
		"""SCPI: WAVeform:MT:SPACing \n
		Snippet: value: float = driver.waveform.mt.get_spacing() \n
		Sets the tone spacing. \n
			:return: spacing: float Range: 100 to 1e+07
		"""
		response = self._core.io.query_str('WAVeform:MT:SPACing?')
		return Conversions.str_to_float(response)

	def set_spacing(self, spacing: float) -> None:
		"""SCPI: WAVeform:MT:SPACing \n
		Snippet: driver.waveform.mt.set_spacing(spacing = 1.0) \n
		Sets the tone spacing. \n
			:param spacing: float Range: 100 to 1e+07
		"""
		param = Conversions.decimal_value_to_str(spacing)
		self._core.io.write(f'WAVeform:MT:SPACing {param}')
